@@ -82,7 +82,7 @@ class App:
 
     def default_response(self, response):
         response.status_code = 404
-        response.body = self.template("error-404.html")
+        response.body = self.custom_template("selfpages", "error-404.html")
 
     def find_handler(self, request_path):
         for path, handler in self.routes.items():
