@@ -17,5 +17,5 @@ class DefaultExceptionHandler:
 
     def handle_error(self, request, response, error):
         response.status_code = 500
-        response.body = self.app.custom_template(r"arc/selfpages",
-                                                 "error-500.html", context={"error": str(error)})
+        response.body = self.app.custom_template(r"selfpages",
+                                                 "index.html", context={"error": str(error)})
